package
Version:
v0.0.0-...-2a7bb96
Opens a new window with list of versions in this module.
Published: Sep 20, 2019
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Document struct {
Email string `json:"email"`
Username string `json:"username"`
Domain string `json:"domain"`
DomainNoTLD string `json:"domain_notld"`
Tld string `json:"tld"`
Password string `json:"password"`
PasswordLen int `json:"password_length"`
Source int `json:"source"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.